==> prestashop_1.4.0.2.zip: prestashop/modules/productscategory/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{productscategory}prestashop>productscategory_db33983df8ef521000b0ab60dcb5a83f'] = 'Dans la même catégorie';
$_MODULE['<{productscategory}prestashop>productscategory_c167dc9a6cdefdab35fb3b5e325cc815'] = 'Affiche la liste des produits dans la même catégorie que celui affiché';
$_MODULE['<{productscategory}prestashop>productscategory_e316b4398212d473f7f53c7728fe1c37'] = 'Paramètres mis à jour avec succès';
$_MODULE['<{productscategory}prestashop>productscategory_f4f70727dc34561dfde1a3c529b6205c'] = 'Paramètres';
$_MODULE['<{productscategory}prestashop>productscategory_b6bf131edd323320bac67303a3f4de8a'] = 'Afficher le prix du produit';
$_MODULE['<{productscategory}prestashop>productscategory_00d23a76e43b46dae9ec7aa9dcbebb32'] = 'Activé';
$_MODULE['<{productscategory}prestashop>productscategory_b9f5c797ebbf55adccdd8539a65a0241'] = 'Désactivé';
$_MODULE['<{productscategory}prestashop>productscategory_70f9a895dc3273d34a7f6d14642708ec'] = 'Afficher le prix du produit dans le block';
$_MODULE['<{productscategory}prestashop>productscategory_c9cc8cce247e49bae79f15173ce97354'] = 'Enregistrer';
$_MODULE['<{productscategory}prestashop>productscategory_3029e678e2d59c6f5e1d450e9b6c03a7'] = 'Dans la même catégorie';
$_MODULE['<{productscategory}prestashop>productscategory_dd1f775e443ff3b9a89270713580a51b'] = 'Précédent';
$_MODULE['<{productscategory}prestashop>productscategory_4351cfebe4b61d8aa5efa1d020710005'] = 'Voir';
$_MODULE['<{productscategory}prestashop>productscategory_10ac3d04253ef7e1ddc73e6091c0cd55'] = 'Suivant';

==> prestashop_1.4.0.7.zip: prestashop/modules/productscategory/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{productscategory}prestashop>productscategory_db33983df8ef521000b0ab60dcb5a83f'] = 'Dans la même catégorie';
$_MODULE['<{productscategory}prestashop>productscategory_c167dc9a6cdefdab35fb3b5e325cc815'] = 'Affiche la liste des produits dans la même catégorie que celui affiché';
$_MODULE['<{productscategory}prestashop>productscategory_462390017ab0938911d2d4e964c0cab7'] = 'Paramètres mis à jour avec succès';
$_MODULE['<{productscategory}prestashop>productscategory_f4f70727dc34561dfde1a3c529b6205c'] = 'Paramètres';
$_MODULE['<{productscategory}prestashop>productscategory_b6bf131edd323320bac67303a3f4de8a'] = 'Afficher le prix du produit';
$_MODULE['<{productscategory}prestashop>productscategory_00d23a76e43b46dae9ec7aa9dcbebb32'] = 'Activé';
$_MODULE['<{productscategory}prestashop>productscategory_b9f5c797ebbf55adccdd8539a65a0241'] = 'Désactivé';
$_MODULE['<{productscategory}prestashop>productscategory_70f9a895dc3273d34a7f6d14642708ec'] = 'Afficher le prix du produit dans le block';
$_MODULE['<{productscategory}prestashop>productscategory_c9cc8cce247e49bae79f15173ce97354'] = 'Enregistrer';
$_MODULE['<{productscategory}prestashop>productscategory_a2aa72e389171b993f3f2bfa529e436c'] = 'autres produits dans la même catégorie';
$_MODULE['<{productscategory}prestashop>productscategory_dd1f775e443ff3b9a89270713580a51b'] = 'Précédent';
$_MODULE['<{productscategory}prestashop>productscategory_4351cfebe4b61d8aa5efa1d020710005'] = 'Voir';
$_MODULE['<{productscategory}prestashop>productscategory_10ac3d04253ef7e1ddc73e6091c0cd55'] = 'Suivant';
